#
# spec file for package perl-Lingua-Translit
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Lingua-Translit
Name:           perl-Lingua-Translit
Version:        0.29
Release:        1.11
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Transliterates text between writing systems
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AL/ALINKE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Lingua::Translit can be used to convert text from one writing system to
another, based on national or international transliteration tables. Where
possible a reverse transliteration is supported.

The term 'transliteration' describes the conversion of text from one
writing system or alphabet to another one. The conversion is ideally
unique, mapping one character to exactly one character, so the original
spelling can be reconstructed. Practically this is not always the case and
one single letter of the original alphabet can be transcribed as two, three
or even more letters.

Furthermore there is more than one transliteration scheme for one writing
system. Therefore it is an important and necessary information, which
scheme will be or has been used to transliterate a text, to work
integrative and be able to reconstruct the original data.

Reconstruction is a problem though for non-unique transliterations, if no
language specific knowledge is available as the resulting clusters of
letters may be ambiguous. For example, the Greek character "PSI" maps to
"ps", but "ps" could also result from the sequence "PI", "SIGMA" since "PI"
maps to "p" and "SIGMA" maps to s. If a transliteration table leads to
ambiguous conversions, the provided table cannot be used reverse.

Otherwise the table can be used in both directions, if appreciated. So if
ISO 9 is originally created to convert Cyrillic letters to the Latin
alphabet, the reverse transliteration will transform Latin letters to
Cyrillic.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README translit

%changelog
* Thu Jun 16 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.29
  see /usr/share/doc/packages/perl-Lingua-Translit/Changes
  0.29  -- 2022-06-15
  * Fixed numeric zero and empty string argument handling in translit() &
    translit_reverse().
* Tue Oct 17 2017 coolo@suse.com
- updated to 0.28
  see /usr/share/doc/packages/perl-Lingua-Translit/Changes
  0.28  -- 2017-10-16
  * Fixed wrong capitalised Cyrillic A in several context rules of both
    "BGN/PCGN RUS Standard" and "BGN/PCGN RUS Strict" - thanks to Nikola
    Lečić for providing the fix!
  * Spelling corrections in man page - thanks to Lucas Kanashiro for
    providing a patch!
  * Updated copyright (Netzum Sorglos Software GmbH).
* Thu Apr 27 2017 coolo@suse.com
- updated to 0.27
  see /usr/share/doc/packages/perl-Lingua-Translit/Changes
  0.27  -- 2017-04-26
  * Added "BGN/PCGN RUS Standard" and "BGN/PCGN RUS Strict"
    transliterations. Thanks to Nikola Lečić for contributing these tables!
* Wed Jul 20 2016 mlin@suse.com
- Initial import from version 0.26
  * See changelog http://cpansearch.perl.org/src/ALINKE/Lingua-Translit-0.26/Changes
